[GRASS-SVN] r47931 - grass/trunk/lib/db/dbmi_client

svn_grass at osgeo.org svn_grass at osgeo.org
Mon Aug 29 04:38:18 EDT 2011


Author: mmetz
Date: 2011-08-29 01:38:18 -0700 (Mon, 29 Aug 2011)
New Revision: 47931

Modified:
   grass/trunk/lib/db/dbmi_client/shutdown.c
Log:
fix for ticket #1158, to be backported after G_wait is backported

Modified: grass/trunk/lib/db/dbmi_client/shutdown.c
===================================================================
--- grass/trunk/lib/db/dbmi_client/shutdown.c	2011-08-29 07:20:26 UTC (rev 47930)
+++ grass/trunk/lib/db/dbmi_client/shutdown.c	2011-08-29 08:38:18 UTC (rev 47931)
@@ -59,8 +59,8 @@
     status = -1;
 
 #ifdef __MINGW32__
-    /* TODO: convert status to something like from wait? */
-    _cwait(&status, driver->pid, WAIT_CHILD);
+    /* convert status according to return code of G_wait() */
+    status = G_wait(driver->pid) == -1 ? -1 : 0;
 #else
     /* TODO: Should not be here waitpid() ? */
     while ((pid = wait(&status)) > 0 && pid != driver->pid) {



More information about the grass-commit mailing list